.. Please use the following format when entering a changelog record:

   <<version>>
   -----------

   - <<message>> [<<user(s)>>]

   Where all '<<_>>' items are dynamic. See also existing records for examples.
   Please limit line length to 78-80 chars maximum.
   Release dates do not need to be contained within this document.

0.x
---

- ? []

0.0
---

- Initialized project [pumazi]
